==> TENxVisiumData_1.0.2.tar.gz: TENxVisiumData/inst/doc/vignette.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(message = FALSE, warning = FALSE, error = FALSE)

## -----------------------------------------------------------------------------
library(ExperimentHub)
eh <- ExperimentHub()
(q <- query(eh, "TENxVisium"))

## -----------------------------------------------------------------------------
library(TENxVisiumData)
spe <- HumanHeart_v3.13()

## -----------------------------------------------------------------------------
library(ExperimentHub)
eh <- ExperimentHub()        # initialize hub instance
q <- query(eh, "TENxVisium") # retrieve 'TENxVisiumData' records
id <- q$ah_id[1]             # specify dataset ID to load
spe <- eh[[id]]              # load specified dataset

## -----------------------------------------------------------------------------
spe

## -----------------------------------------------------------------------------
head(spatialCoords(spe))

## -----------------------------------------------------------------------------
head(spatialData(spe))

## -----------------------------------------------------------------------------
imgData(spe)

## -----------------------------------------------------------------------------
spe <- MouseBrainSagittalAnterior_v3.13()
table(spe$sample_id)

## -----------------------------------------------------------------------------
spe <- HumanOvarianCancer_v3.13()
altExpNames(spe)

## -----------------------------------------------------------------------------
sessionInfo()

==> TENxVisiumData_1.12.0.tar.gz: TENxVisiumData/inst/doc/vignette.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(message = FALSE, warning = FALSE, error = FALSE)

## -----------------------------------------------------------------------------
library(ExperimentHub)
eh <- ExperimentHub()
(q <- query(eh, "TENxVisium"))

## -----------------------------------------------------------------------------
library(TENxVisiumData)
spe <- HumanHeart()

## -----------------------------------------------------------------------------
library(ExperimentHub)
eh <- ExperimentHub()        # initialize hub instance
q <- query(eh, "TENxVisium") # retrieve 'TENxVisiumData' records
id <- q$ah_id[1]             # specify dataset ID to load
spe <- eh[[id]]              # load specified dataset

## -----------------------------------------------------------------------------
spe

## -----------------------------------------------------------------------------
head(spatialCoords(spe))

## -----------------------------------------------------------------------------
head(spatialData(spe))

## -----------------------------------------------------------------------------
imgData(spe)

## -----------------------------------------------------------------------------
spe <- MouseBrainSagittalAnterior()
table(spe$sample_id)

## -----------------------------------------------------------------------------
spe <- HumanOvarianCancer()
altExpNames(spe)

## -----------------------------------------------------------------------------
sessionInfo()
